pub enum LogStreamRequest {
Connect {
socket: Socket,
opts: LogStreamOptions,
control_handle: LogStreamControlHandle,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: LogStreamControlHandle,
method_type: MethodType,
},
}Variants
Connect
Enables clients to stream all logs stored in the Archivist. Expects a stream socket handle that can be written to.
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: LogStreamControlHandle
method_type: MethodTypeImplementations
Sourceimpl LogStreamRequest
impl LogStreamRequest
pub fn into_connect( self, ) -> Option<(Socket, LogStreamOptions, LogStreamControlHandle)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL