LogInterestSelector

Struct LogInterestSelector 

pub struct LogInterestSelector {
    pub selector: ComponentSelector,
    pub interest: Interest,
}

Fields

selector: ComponentSelector

Matches the components for which the interest will be requested.

interest: Interest

The interest level that will be sent to components matching the selector.