pub struct SystemActivityMonitorGetNextEventResponder { /* private fields */ }Implementations
Sourceimpl SystemActivityMonitorGetNextEventResponder
impl SystemActivityMonitorGetNextEventResponder
Sourcepub fn send(self, event: &SystemActivityEvent) -> Result<(), Error>
pub fn send(self, event: &SystemActivityEvent) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
event: &SystemActivityEvent,
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, event: &SystemActivityEvent, ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.