pub struct SystemActivityMonitorGetNextEventResponse {
pub event: SystemActivityEvent,
}Fields
event: SystemActivityEventTrait Implementations
Sourceimpl Clone for SystemActivityMonitorGetNextEventResponse
impl Clone for SystemActivityMonitorGetNextEventResponse
Sourcefn clone(&self) -> SystemActivityMonitorGetNextEventResponse
fn clone(&self) -> SystemActivityMonitorGetNextEventResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<SystemActivityMonitorGetNextEventResponse, D> for SystemActivityMonitorGetNextEventResponsewhere
D: ResourceDialect,
impl<D> Decode<SystemActivityMonitorGetNextEventResponse, D> for SystemActivityMonitorGetNextEventResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> SystemActivityMonitorGetNextEventResponse
fn new_empty() -> SystemActivityMonitorGetNextEventResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<SystemActivityMonitorGetNextEventResponse, D> for &SystemActivityMonitorGetNextEventResponsewhere
D: ResourceDialect,
impl<D> Encode<SystemActivityMonitorGetNextEventResponse, D> for &SystemActivityMonitorGetNextEventResponsewhere
D: ResourceDialect,
impl Persistable for SystemActivityMonitorGetNextEventResponse
impl StructuralPartialEq for SystemActivityMonitorGetNextEventResponse
Sourceimpl TypeMarker for SystemActivityMonitorGetNextEventResponse
impl TypeMarker for SystemActivityMonitorGetNextEventResponse
Sourcetype Owned = SystemActivityMonitorGetNextEventResponse
type Owned = SystemActivityMonitorGetNextEventResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for SystemActivityMonitorGetNextEventResponse
impl ValueTypeMarker for SystemActivityMonitorGetNextEventResponse
Sourcetype Borrowed<'a> = &'a SystemActivityMonitorGetNextEventResponse
type Borrowed<'a> = &'a SystemActivityMonitorGetNextEventResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<SystemActivityMonitorGetNextEventResponse as TypeMarker>::Owned,
) -> <SystemActivityMonitorGetNextEventResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<SystemActivityMonitorGetNextEventResponse as TypeMarker>::Owned, ) -> <SystemActivityMonitorGetNextEventResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for SystemActivityMonitorGetNextEventResponse
impl RefUnwindSafe for SystemActivityMonitorGetNextEventResponse
impl Send for SystemActivityMonitorGetNextEventResponse
impl Sync for SystemActivityMonitorGetNextEventResponse
impl Unpin for SystemActivityMonitorGetNextEventResponse
impl UnsafeUnpin for SystemActivityMonitorGetNextEventResponse
impl UnwindSafe for SystemActivityMonitorGetNextEventResponse