pub struct SystemActivityMonitorMarker;Trait Implementations
Sourceimpl Clone for SystemActivityMonitorMarker
impl Clone for SystemActivityMonitorMarker
Sourcefn clone(&self) -> SystemActivityMonitorMarker
fn clone(&self) -> SystemActivityMonitorMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SystemActivityMonitorMarker
Sourceimpl Debug for SystemActivityMonitorMarker
impl Debug for SystemActivityMonitorMarker
Sourceimpl DiscoverableProtocolMarker for SystemActivityMonitorMarker
impl DiscoverableProtocolMarker for SystemActivityMonitorMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
impl Eq for SystemActivityMonitorMarker
Sourceimpl Hash for SystemActivityMonitorMarker
impl Hash for SystemActivityMonitorMarker
Sourceimpl Ord for SystemActivityMonitorMarker
impl Ord for SystemActivityMonitorMarker
Sourcefn cmp(&self, other: &SystemActivityMonitorMarker) -> Ordering
fn cmp(&self, other: &SystemActivityMonitorMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for SystemActivityMonitorMarker
impl PartialOrd for SystemActivityMonitorMarker
Sourceimpl ProtocolMarker for SystemActivityMonitorMarker
impl ProtocolMarker for SystemActivityMonitorMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.diagnostics.SystemActivityMonitor"
const DEBUG_NAME: &'static str = "fuchsia.diagnostics.SystemActivityMonitor"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = SystemActivityMonitorProxy
type Proxy = SystemActivityMonitorProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = SystemActivityMonitorRequestStream
type RequestStream = SystemActivityMonitorRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = SystemActivityMonitorSynchronousProxy
type SynchronousProxy = SystemActivityMonitorSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for SystemActivityMonitorMarker